/*
 *************************************************************************
 * Copyright (c) 2006 Innovent Solutions, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Scott Rosenbaum 
 *************************************************************************
 */

package com.innoventsolutions.birt.oda.ez_example;

import org.eclipse.datatools.connectivity.oda.IConnection;
import org.eclipse.datatools.connectivity.oda.IDriver;
import org.eclipse.datatools.connectivity.oda.LogConfiguration;
import org.eclipse.datatools.connectivity.oda.OdaException;

/**
 * The IDriver interface is what is specified in the plugin.xml 
 * configuration as the class that is the basis for the entire ODA extension
 * 
 */
public class ExampleDriver implements IDriver
{
	/*
	 * @see org.eclipse.datatools.connectivity.oda.IDriver#getConnection(java.lang.String)
	 */
	public IConnection getConnection( String dataSourceType ) throws OdaException
	{
		return newConnection( dataSourceType );
	}
	
	/**
	 * Override to return a specific IConnection instance based on the 
	 * type of data source.
	 * @param connectionType	the type of the IConnection to instantiate for the data source.
	 * @return	an IConnection instance.
	 * @throws OdaException	if data source error occurs.
	 */
	protected IConnection newConnection( String dataSourceType ) throws OdaException
	{
		// For this example we are just going to use one Connection
		return new ExampleConnection();
	}

	/*
	 * @see org.eclipse.datatools.connectivity.oda.IDriver#setLogConfiguration(org.eclipse.datatools.connectivity.oda.LogConfiguration)
	 */
	public void setLogConfiguration( LogConfiguration logConfig ) throws OdaException
	{
		// do nothing; assumes simple driver has no logging
	}

	/*
	 * @see org.eclipse.datatools.connectivity.oda.IDriver#getMaxConnections()
	 */
	public int getMaxConnections() throws OdaException
	{
		return 0;	// no limit
	}
	
	/*
	 * @see org.eclipse.datatools.connectivity.oda.IDriver#setAppContext(java.lang.Object)
	 */
	public void setAppContext( Object context ) throws OdaException
	{
	    // do nothing; assumes no support for pass-through context
	}

}
