/*
 *************************************************************************
 * Copyright (c) 2006 Innovent Solutions, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Scott Rosenbaum 
 *************************************************************************
 */

package com.innoventsolutions.birt.oda.ez_example;

import org.eclipse.datatools.connectivity.oda.IResultSetMetaData;
import org.eclipse.datatools.connectivity.oda.OdaException;

/**
 * This class describes the data that is returned by this particular ResultSet.
 * For this example we use hard coded data types and column names. All of the
 * columns are defined as strings.
 * 
 */
public class ExampleResultSetMetaData implements IResultSetMetaData {
	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getColumnCount()
	 * 
	 * Normally want to derive from the actual object that is being passed in
	 * 
	 */
	public int getColumnCount() throws OdaException {
		return 5;
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getColumnName(int)
	 * 
	 * first is a key work in BirtScript so I used a little spanish. These names
	 * will show up in the computed columns field.
	 * 
	 */
	public String getColumnName(int index) throws OdaException {
		switch (index) {
		case 1:
			return "primero";
		case 2:
			return "segundo";
		case 3:
			return "tercero";
		case 4:
			return "cuarto";
		case 5:
			return "quinto";

		default:
			return "invalid column " + index;
		}
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getColumnLabel(int)
	 */
	public String getColumnLabel(int index) throws OdaException {
		return getColumnName(index) + " label";
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getColumnType(int)
	 * 
	 * This example only supports String data types.
	 * 
	 */
	public int getColumnType(int index) throws OdaException {

		// the index to columns is always base 1
		assertIndexValid(index);
		return DataTypes.STRING;
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getColumnTypeName(int)
	 */
	public String getColumnTypeName(int index) throws OdaException {
		// I don't think this is even used.
		return "String";
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getColumnDisplayLength(int)
	 */
	public int getColumnDisplayLength(int index) throws OdaException {
		return 0;
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getPrecision(int)
	 */
	public int getPrecision(int index) throws OdaException {
		return -1;
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#getScale(int)
	 */
	public int getScale(int index) throws OdaException {
		return -1;
	}

	/**
	 * @see org.eclipse.datatools.connectivity.oda.IResultSetMetaData#isNullable(int)
	 */
	public int isNullable(int index) throws OdaException {
		return IResultSetMetaData.columnNullableUnknown;
	}

	private void assertIndexValid(int index) throws OdaException {
		if (index < 1 || index > getColumnCount() )
			throw new OdaException("Invalid Column Index: " + index); //$NON-NLS-1$
	}
}
